# pyperclip-stubs

[![QA](https://github.com/Tatsh/pyperclip-stubs/actions/workflows/qa.yml/badge.svg)](https://github.com/Tatsh/pyperclip-stubs/actions/workflows/qa.yml)
[![PyPI - Version](https://img.shields.io/pypi/v/pyperclip-stubs)](https://pypi.org/project/pyperclip-stubs/)
[![GitHub tag (with filter)](https://img.shields.io/github/v/tag/Tatsh/pyperclip-stubs)](https://github.com/Tatsh/pyperclip-stubs/tags)
[![License](https://img.shields.io/github/license/Tatsh/pyperclip-stubs)](https://github.com/Tatsh/pyperclip-stubs/blob/master/LICENSE.txt)
[![GitHub commits since latest release (by SemVer including pre-releases)](https://img.shields.io/github/commits-since/Tatsh/pyperclip-stubs/v0.0.3/master)](https://github.com/Tatsh/pyperclip-stubs/compare/v0.0.3...master)

## Deprecation notice

Please use [types-pyperclip](https://pypi.org/project/types-pyperclip/).

## Description

PEP 561 type stubs for pyperclip.

## Installation

### Poetry

```shell
poetry add pyperclip-stubs
```

### Pip

```shell
pip install pyperclip-stubs
```
